<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */

function optionsframework_option_name() {

	// This gets the theme name from the stylesheet
	$themename = wp_get_theme();
	$themename = preg_replace("/\W/", "_", strtolower($themename) );

	$optionsframework_settings = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = $themename;
	update_option( 'optionsframework', $optionsframework_settings );
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'Aocean'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function optionsframework_options() {

	// Test data
	$test_array = array(
		'one' => __('One', 'Aocean'),
		'two' => __('Two', 'Aocean'),
		'three' => __('Three', 'Aocean'),
		'four' => __('Four', 'Aocean'),
		'five' => __('Five', 'Aocean')
	);

	// Multicheck Array
	$multicheck_array = array(
		'one' => __('French Toast', 'Aocean'),
		'two' => __('Pancake', 'Aocean'),
		'three' => __('Omelette', 'Aocean'),
		'four' => __('Crepe', 'Aocean'),
		'five' => __('Waffle', 'Aocean')
	);

	// Multicheck Defaults
	$multicheck_defaults = array(
		'one' => '1',
		'five' => '1'
	);

	// Background Defaults
	$background_defaults = array(
		'color' => '',
		'image' => '',
		'repeat' => 'repeat',
		'position' => 'top center',
		'attachment'=>'scroll' );

	// Typography Defaults
	$typography_defaults = array(
		'size' => '15px',
		'face' => 'georgia',
		'style' => 'bold',
		'color' => '#bada55' );

	// Typography Options
	$typography_options = array(
		'sizes' => array( '6','12','14','16','20' ),
		'faces' => array( 'Helvetica Neue' => 'Helvetica Neue','Arial' => 'Arial' ),
		'styles' => array( 'normal' => 'Normal','bold' => 'Bold' ),
		'color' => false
	);

	// Pull all the categories into an array
	$options_categories = array();
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
		$options_categories[$category->cat_ID] = $category->cat_name;
	}

	// Pull all tags into an array
	$options_tags = array();
	$options_tags_obj = get_tags();
	foreach ( $options_tags_obj as $tag ) {
		$options_tags[$tag->term_id] = $tag->name;
	}


	// Pull all the pages into an array
	$options_pages = array();
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
		$options_pages[$page->ID] = $page->post_title;
	}

	// If using image radio buttons, define a directory path
	$imagepath =  get_template_directory_uri() . '/images/';

	$options = array();
	
	// -----------------------------
	// General Tab
	// -----------------------------

	$options[] = array(
		'name' => __('General', 'Aocean'),
		'type' => 'heading');
	
	$options[] = array(
		'name' => __('Custom Favicon', 'Aocean'),
		'desc' => __('Upload a 16x16px Png/Gif image that will be your favicon.', 'Aocean'),
		'id' => 'favicon',
		'type' => 'upload');
		
	$options[] = array(
		'name' => __('Custom CSS', 'Aocean'),
		'desc' => __('Want to add any custom CSS code? Put in here.', 'Aocean'),
		'id' => 'custom_css',
		'std' => '',
		'type' => 'textarea');

	$options[] = array(
		'name' => __('Custom JS', 'Aocean'),
		'desc' => __('Paste your Custom JS code here. It will be inserted before the closing body tag of your theme.', 'Aocean'),
		'id' => 'tracking_code',
		'std' => 'Default Text',
		'type' => 'textarea');


	// -----------------------------
	// Header
	// -----------------------------

	$options[] = array(
		'name' => __('Header', 'Aocean'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Custom Logo', 'Aocean'),
		'desc' => __('Upload custom logo image.', 'Aocean'),
		'id' => 'custom_logo',
		'type' => 'upload');
	
	$options[] = array(
		'name' 		=> __( 'Site Title color', 'Aocean' ),
		'desc' 		=> __( 'You can change the site title color.', 'Aocean' ),
		'id' 			=> 'logo_text_color',
		'std' 		=> '',
		'type' 		=> 'color' 
	);
	
	$options[] = array(
		'name' 		=> __( 'Site Description color', 'Aocean' ),
		'desc' 		=> __( 'You can change the site description color.', 'Aocean' ),
		'id' 			=> 'site_description_color',
		'std' 		=> '',
		'type' 		=> 'color' 
	);

	
	$options[] = array(
		'name' => __('Site Description', 'Aocean'),
		'desc' => __('If you want to hide the description that appears next to your logo.', 'Aocean'),
		'id' => 'site_description',
		'std' => '',
		'type' => 'checkbox');
		
	// -----------------------------
	// Styling Tab
	// -----------------------------
	
		
	$options[] = array(
		'name' => __('Styling', 'Aocean'),
		'type' => 'heading');

	$options[] = array(
		'name' 		=> __( 'Theme color', 'Aocean' ),
		'desc' 		=> __( 'You can change the theme color. This will reflect in links, buttons and many others.', 'Aocean'),
		'id' 			=> 'theme_primary_color',
		'std' 		=> '',
		'type' 		=> 'color' 
	);
	
	$options[] = array(
		'name' => __('Social Icon Color', ''),
		'desc' => __('Chnage Your Social Icon Color', ''),
		'id' => 'social_icon_bg_color',
		'std' => '',
		'type' => 'color');
	
	$options[] = array(
		'name' =>  __('Header Background', 'Aocean'),
		'desc' => __('Change the Header background color or upload background image.', 'Aocean'),
		'id' => 'header_color',
		'std' => $background_defaults,
		'type' => 'background' );

	$options[] = array(
		'name' =>  __('Footer Widget Background', 'Aocean'),
		'desc' => __('Change the Footer Widget background color or upload background image.', 'Aocean'),
		'id' => 'footer_widget_color',
		'std' => $background_defaults,
		'type' => 'background' );

	$options[] = array(
		'name' =>  __('Footer Background', 'Aocean'),
		'desc' => __('Change the Footer background color or upload background image.', 'Aocean'),
		'id' => 'footer_color',
		'std' => $background_defaults,
		'type' => 'background' );
		
	
	// -----------------------------
	// Advertising Tab
	// -----------------------------
		
	$options[] = array(
		'name' => __('Advertising', ''),
		'type' => 'heading');
	
	$options[] = array(
		'name' => __('Ad size is 468 X 60', ''),
		'desc' => __('Add your banner\'s code. It appears on header', ''),
		'id' => 'header_ad_468',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'name' => __('Ad size is 728 X 90', ''),
		'desc' => __('Add your banner\'s code. It appears on footer', ''),
		'id' => 'footer_ad_728',
		'std' => '',
		'type' => 'textarea');
		
	// -----------------------------
	// Footer Tab
	// -----------------------------

		
	$options[] = array(
		'name' => __('Footer', 'Aocean'),
		'type' => 'heading');
		
	$options[] = array(
		'name' 		=> __( 'Footer Widget Heading Text color', 'Aocean' ),
		'desc' 		=> __( 'You can change the theme footer widget heading text color.', 'Aocean'),
		'id' 			=> 'footer_widget_text_color',
		'std' 		=> '',
		'type' 		=> 'color' 
	);
	
	$options[] = array(
		'name' 		=> __( 'Footer Widget Link color', 'Aocean' ),
		'desc' 		=> __( 'You can change the theme footer widget link color.', 'Aocean'),
		'id' 			=> 'footer_widget_link_color',
		'std' 		=> '',
		'type' 		=> 'color' 
	);
	
	$options[] = array(
		'name' => __('Footer Copyright', 'Aocean'),
		'desc' => __('Replace the footer copyright text.', 'Aocean'),
		'id' => 'copyright',
		'std' => '',
		'type' => 'textarea');
	


	/**
	 * For $settings options see:
	 * http://codex.wordpress.org/Function_Reference/wp_editor
	 *
	 * 'media_buttons' are not supported as there is no post to attach items to
	 * 'textarea_name' is set by the 'id' you choose
	 */

	$wp_editor_settings = array(
		'wpautop' => true, // Default
		'textarea_rows' => 5,
		'tinymce' => array( 'plugins' => 'wordpress' )
	);


	return $options;
}